***********
GoudaPath
***********

Classes for constant-time updates for streaming statistics

.. autoclass:: gouda.MMean
  :members:
  :special-members:

.. autoclass:: gouda.MMeanArray
  :members:
  :special-members:

.. autoclass:: gouda.MStddev
  :members:
  :special-members:

.. autoclass:: gouda.MStddevArray
  :members:
  :special-members:
